==> TuxGuitar-0.8-src.tar.gz: TuxGuitar-0.8-src/src/org/herac/tuxguitar/gui/items/tool/FileToolItems.java <==
/*
 * Created on 02-dic-2005
 *
 * TODO To change the template for this generated file go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
package org.herac.tuxguitar.gui.items.tool;

import org.eclipse.swt.SWT;
import org.eclipse.swt.widgets.ToolBar;
import org.eclipse.swt.widgets.ToolItem;
import org.herac.tuxguitar.gui.SystemImages;
import org.herac.tuxguitar.gui.TablatureEditor;
import org.herac.tuxguitar.gui.TuxGuitar;
import org.herac.tuxguitar.gui.actions.file.NewFileAction;
import org.herac.tuxguitar.gui.actions.file.OpenFileAction;
import org.herac.tuxguitar.gui.actions.file.PrintAction;
import org.herac.tuxguitar.gui.actions.file.PrintPreviewAction;
import org.herac.tuxguitar.gui.actions.file.SaveAsFileAction;
import org.herac.tuxguitar.gui.actions.file.SaveFileAction;
import org.herac.tuxguitar.gui.items.ItemContainer;
/**
 * @author julian
 *
 * TODO To change the template for this generated type comment go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
public class FileToolItems implements ItemContainer {
    public static final String NAME = "FILE_ITEMS";
    private TablatureEditor tablatureEditor;
    private ToolBar toolBar;   
    private ToolItem newSong;
    private ToolItem openSong;
    private ToolItem saveSong;
    private ToolItem saveAsSong;
    private ToolItem printSong;
    private ToolItem printPreviewSong;
    
    public FileToolItems(TablatureEditor tablatureEditor,ToolBar toolBar){
        this.tablatureEditor = tablatureEditor;
        this.toolBar = toolBar;
    }
   
    public void showItems(){                       
        newSong = new ToolItem(toolBar, SWT.PUSH);
        newSong.setImage(SystemImages.NEW_IMAGE);
        newSong.addSelectionListener(TuxGuitar.instance().getAction(NewFileAction.NAME));
       
        openSong = new ToolItem(toolBar, SWT.PUSH);
        openSong.setImage(SystemImages.OPEN_IMAGE);
        openSong.addSelectionListener(TuxGuitar.instance().getAction(OpenFileAction.NAME));

        saveSong = new ToolItem(toolBar, SWT.PUSH);
        saveSong.setImage(SystemImages.SAVE_IMAGE);
        saveSong.addSelectionListener(TuxGuitar.instance().getAction(SaveFileAction.NAME));
    
        saveAsSong = new ToolItem(toolBar, SWT.PUSH);
        saveAsSong.setImage(SystemImages.SAVE_AS_IMAGE);
        saveAsSong.addSelectionListener(TuxGuitar.instance().getAction(SaveAsFileAction.NAME));        
        
        printSong = new ToolItem(toolBar, SWT.PUSH);
        printSong.setImage(SystemImages.PRINT_IMAGE);
        printSong.addSelectionListener(TuxGuitar.instance().getAction(PrintAction.NAME));        
        
        printPreviewSong = new ToolItem(toolBar, SWT.PUSH);
        printPreviewSong.setImage(SystemImages.PRINT_PREVIEW_IMAGE);
        printPreviewSong.addSelectionListener(TuxGuitar.instance().getAction(PrintPreviewAction.NAME)); 
        
        this.loadProperties();
    }
    
    
    public void update(){
        
    }
    
    public void loadProperties(){
        this.newSong.setToolTipText(TuxGuitar.getProperty("file.new"));  
        this.openSong.setToolTipText(TuxGuitar.getProperty("file.open"));  
        this.saveSong.setToolTipText(TuxGuitar.getProperty("file.save"));
        this.saveAsSong.setToolTipText(TuxGuitar.getProperty("file.save-as"));
        this.printSong.setToolTipText(TuxGuitar.getProperty("file.print"));
        this.printPreviewSong.setToolTipText(TuxGuitar.getProperty("file.print-preview"));
    }        
}

==> TuxGuitar-0.9-src.tar.gz: TuxGuitar-0.9-src/src/org/herac/tuxguitar/gui/items/tool/FileToolItems.java <==
/*
 * Created on 02-dic-2005
 *
 * TODO To change the template for this generated file go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
package org.herac.tuxguitar.gui.items.tool;

import org.eclipse.swt.SWT;
import org.eclipse.swt.widgets.ToolBar;
import org.eclipse.swt.widgets.ToolItem;
import org.herac.tuxguitar.gui.SystemImages;
import org.herac.tuxguitar.gui.TuxGuitar;
import org.herac.tuxguitar.gui.actions.file.NewFileAction;
import org.herac.tuxguitar.gui.actions.file.OpenFileAction;
import org.herac.tuxguitar.gui.actions.file.PrintAction;
import org.herac.tuxguitar.gui.actions.file.PrintPreviewAction;
import org.herac.tuxguitar.gui.actions.file.SaveAsFileAction;
import org.herac.tuxguitar.gui.actions.file.SaveFileAction;
import org.herac.tuxguitar.gui.items.ToolItems;
/**
 * @author julian
 *
 * TODO To change the template for this generated type comment go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
public class FileToolItems extends ToolItems {
    public static final String NAME = "file.items";
    private ToolBar toolBar;   
    private ToolItem newSong;
    private ToolItem openSong;
    private ToolItem saveSong;
    private ToolItem saveAsSong;
    private ToolItem printSong;
    private ToolItem printPreviewSong;
    
    public FileToolItems(){
    	super(NAME);
    }
   
    public void showItems(ToolBar toolBar){
    	this.toolBar = toolBar;                 
        newSong = new ToolItem(toolBar, SWT.PUSH);
        newSong.setImage(SystemImages.NEW_IMAGE);
        newSong.addSelectionListener(TuxGuitar.instance().getAction(NewFileAction.NAME));
       
        openSong = new ToolItem(toolBar, SWT.PUSH);
        openSong.setImage(SystemImages.OPEN_IMAGE);
        openSong.addSelectionListener(TuxGuitar.instance().getAction(OpenFileAction.NAME));

        saveSong = new ToolItem(toolBar, SWT.PUSH);
        saveSong.setImage(SystemImages.SAVE_IMAGE);
        saveSong.addSelectionListener(TuxGuitar.instance().getAction(SaveFileAction.NAME));
    
        saveAsSong = new ToolItem(toolBar, SWT.PUSH);
        saveAsSong.setImage(SystemImages.SAVE_AS_IMAGE);
        saveAsSong.addSelectionListener(TuxGuitar.instance().getAction(SaveAsFileAction.NAME));        
        
        printSong = new ToolItem(toolBar, SWT.PUSH);
        printSong.setImage(SystemImages.PRINT_IMAGE);
        printSong.addSelectionListener(TuxGuitar.instance().getAction(PrintAction.NAME));        
        
        printPreviewSong = new ToolItem(toolBar, SWT.PUSH);
        printPreviewSong.setImage(SystemImages.PRINT_PREVIEW_IMAGE);
        printPreviewSong.addSelectionListener(TuxGuitar.instance().getAction(PrintPreviewAction.NAME)); 
        
        this.loadProperties();
    }
    
    
    public void update(){
        
    }
    
    public void loadProperties(){
        this.newSong.setToolTipText(TuxGuitar.getProperty("file.new"));  
        this.openSong.setToolTipText(TuxGuitar.getProperty("file.open"));  
        this.saveSong.setToolTipText(TuxGuitar.getProperty("file.save"));
        this.saveAsSong.setToolTipText(TuxGuitar.getProperty("file.save-as"));
        this.printSong.setToolTipText(TuxGuitar.getProperty("file.print"));
        this.printPreviewSong.setToolTipText(TuxGuitar.getProperty("file.print-preview"));
    }        
}
